@@ -16,12 +16,14 @@ flush(stderr()); flush(stdout())
 
 ### ** Examples
 
-liveplot("GOOG")
-# Is equivalent to e.g:
-# http://beta1.opencpu.org/R/call/opencpu.demo/liveplot/png?ticker="GOOG"
-# http://beta1.opencpu.org/R/call/opencpu.demo/liveplot/pdf?ticker="GOOG"
-# http://beta1.opencpu.org/R/call/opencpu.demo/liveplot/png?ticker="YHOO"
-# http://beta1.opencpu.org/R/call/opencpu.demo/liveplot/png?ticker="YHOO"&!width=1000&!height=800
+## Not run: 
+##D   liveplot("GOOG")
+##D # Is equivalent to e.g:
+##D # http://beta1.opencpu.org/R/call/opencpu.demo/liveplot/png?ticker="GOOG"
+##D # http://beta1.opencpu.org/R/call/opencpu.demo/liveplot/pdf?ticker="GOOG"
+##D # http://beta1.opencpu.org/R/call/opencpu.demo/liveplot/png?ticker="YHOO"
+##D # http://beta1.opencpu.org/R/call/opencpu.demo/liveplot/png?ticker="YHOO"&!width=1000&!height=800
+## End(Not run)
 
 
 
@@ -39,13 +41,14 @@ flush(stderr()); flush(stdout())
 
 ## plot daily mean NO2 concentrations at three stations
 ## from 1 January 2011 up to today
-library(opencpu.demo);
-nabel("no2",
-      c("Bern", "Basel", "Zürich"),
-      "daily",
-      "free",
-      "2011-01-01",
-      Sys.Date())
+## Not run: 
+##D nabel("no2",
+##D       c("Bern", "Basel", "Lausanne"),
+##D       "daily",
+##D       "free",
+##D       "2011-01-01",
+##D       Sys.Date())
+## End(Not run)
 
 
 
